@@ -75,16 +75,26 @@ func GenerateRequestsFromSchema(schema *openapi3.T, opts formats.InputFormatOpti
 
 	for _, serverURL := range schema.Servers {
 		pathURL := serverURL.URL
+		// Split the server URL into baseURL and serverPath
+		u, err := url.Parse(pathURL)
+		if err != nil {
+			return errors.Wrap(err, "could not parse server url")
+		}
+		baseURL := fmt.Sprintf("%s://%s", u.Scheme, u.Host)
+		serverPath := u.Path
 
 		for path, v := range schema.Paths.Map() {
 			// a path item can have parameters
 			ops := v.Operations()
 			requestPath := path
+			if serverPath != "" {
+				requestPath = serverPath + path
+			}
 			for method, ov := range ops {
 				if err := generateRequestsFromOp(&generateReqOptions{
 					requiredOnly:              opts.RequiredOnly,
 					method:                    method,
-					pathURL:                   pathURL,
+					pathURL:                   baseURL,
 					requestPath:               requestPath,
 					op:                        ov,
 					schema:                    schema,
@@ -193,7 +203,7 @@ func generateRequestsFromOp(opts *generateReqOptions) error {
 			paramValue = value.Schema.Value.Default
 		} else if value.Schema.Value.Example != nil {
 			paramValue = value.Schema.Value.Example
-		} else if value.Schema.Value.Enum != nil && len(value.Schema.Value.Enum) > 0 {
+		} else if len(value.Schema.Value.Enum) > 0 {
 			paramValue = value.Schema.Value.Enum[0]
 		} else {
 			if !opts.opts.SkipFormatValidation {
@@ -406,7 +416,7 @@ schemaLabel:
 	return globalParams, nil
 }
 
-// generateExampleFromSchema generates an example from a schema object
+// GenerateParameterFromSecurityScheme generates an example from a schema object
 func GenerateParameterFromSecurityScheme(scheme *openapi3.SecuritySchemeRef) (*openapi3.Parameter, error) {
 	if !generic.EqualsAny(scheme.Value.Type, "http", "apiKey") {
 		return nil, errorutil.NewWithTag("openapi", "unsupported security scheme type (%s) found in openapi file", scheme.Value.Type)
