@@ -33,6 +33,7 @@ import (
 	"github.com/projectdiscovery/utils/errkit"
 	fileutil "github.com/projectdiscovery/utils/file"
 	osutils "github.com/projectdiscovery/utils/os"
+	unitutils "github.com/projectdiscovery/utils/unit"
 	urlutil "github.com/projectdiscovery/utils/url"
 )
 
@@ -70,6 +71,7 @@ type StandardWriter struct {
 	omitTemplate          bool
 	DisableStdout         bool
 	AddNewLinesOutputFile bool // by default this is only done for stdout
+	KeysToRedact          []string
 }
 
 var decolorizerRegex = regexp.MustCompile(`\x1B\[[0-9;]*[a-zA-Z]`)
@@ -252,6 +254,7 @@ func NewStandardWriter(options *types.Options) (*StandardWriter, error) {
 		storeResponse:    options.StoreResponse,
 		storeResponseDir: options.StoreResponseDir,
 		omitTemplate:     options.OmitTemplate,
+		KeysToRedact:     options.Redact,
 	}
 	return writer, nil
 }
@@ -263,6 +266,13 @@ func (w *StandardWriter) Write(event *ResultEvent) error {
 		event.Template, event.TemplateURL = utils.TemplatePathURL(types.ToString(event.TemplatePath), types.ToString(event.TemplateID))
 	}
 
+	if len(w.KeysToRedact) > 0 {
+		event.Request = redactKeys(event.Request, w.KeysToRedact)
+		event.Response = redactKeys(event.Response, w.KeysToRedact)
+		event.CURLCommand = redactKeys(event.CURLCommand, w.KeysToRedact)
+		event.Matched = redactKeys(event.Matched, w.KeysToRedact)
+	}
+
 	event.Timestamp = time.Now()
 
 	var data []byte
@@ -301,15 +311,24 @@ func (w *StandardWriter) Write(event *ResultEvent) error {
 	return nil
 }
 
+func redactKeys(data string, keysToRedact []string) string {
+	for _, key := range keysToRedact {
+		keyPattern := regexp.MustCompile(fmt.Sprintf(`(?i)(%s\s*[:=]\s*["']?)[^"'\r\n&]+(["'\r\n]?)`, regexp.QuoteMeta(key)))
+		data = keyPattern.ReplaceAllString(data, `$1***$2`)
+	}
+	return data
+}
+
 // JSONLogRequest is a trace/error log request written to file
 type JSONLogRequest struct {
-	Template string      `json:"template"`
-	Type     string      `json:"type"`
-	Input    string      `json:"input"`
-	Address  string      `json:"address"`
-	Error    string      `json:"error"`
-	Kind     string      `json:"kind,omitempty"`
-	Attrs    interface{} `json:"attrs,omitempty"`
+	Template  string      `json:"template"`
+	Type      string      `json:"type"`
+	Input     string      `json:"input"`
+	Timestamp *time.Time  `json:"timestamp,omitempty"`
+	Address   string      `json:"address"`
+	Error     string      `json:"error"`
+	Kind      string      `json:"kind,omitempty"`
+	Attrs     interface{} `json:"attrs,omitempty"`
 }
 
 // Request writes a log the requests trace log
@@ -322,6 +341,10 @@ func (w *StandardWriter) Request(templatePath, input, requestType string, reques
 		Input:    input,
 		Type:     requestType,
 	}
+	if w.timestamp {
+		ts := time.Now()
+		request.Timestamp = &ts
+	}
 	parsed, _ := urlutil.ParseAbsoluteURL(input, false)
 	if parsed != nil {
 		request.Address = parsed.Hostname()
@@ -449,7 +472,7 @@ func (w *StandardWriter) WriteFailure(wrappedEvent *InternalWrappedEvent) error
 	return w.Write(data)
 }
 
-var maxTemplateFileSizeForEncoding = 1024 * 1024
+var maxTemplateFileSizeForEncoding = unitutils.Mega
 
 func (w *StandardWriter) encodeTemplate(templatePath string) string {
 	data, err := os.ReadFile(templatePath)
@@ -502,12 +525,12 @@ func tryParseCause(err error) error {
 	if strings.HasPrefix(msg, "ReadStatusLine:") {
 		// last index is actual error (from rawhttp)
 		parts := strings.Split(msg, ":")
-		return errkit.New(strings.TrimSpace(parts[len(parts)-1]))
+		return errkit.New("%s", strings.TrimSpace(parts[len(parts)-1]))
 	}
 	if strings.Contains(msg, "read ") {
 		// same here
 		parts := strings.Split(msg, ":")
-		return errkit.New(strings.TrimSpace(parts[len(parts)-1]))
+		return errkit.New("%s", strings.TrimSpace(parts[len(parts)-1]))
 	}
 	return err
 }
