@@ -240,7 +240,7 @@ func (c *ReportingClient) Close() {
 				if failed > 0 {
 					msgBuilder.WriteString(fmt.Sprintf(", %d failed", failed))
 				}
-				gologger.Info().Msgf(msgBuilder.String())
+				gologger.Info().Msgf("%v", msgBuilder.String())
 			}
 		}
 	}
@@ -273,7 +273,7 @@ func (c *ReportingClient) CreateIssue(event *output.ResultEvent) error {
 
 		for _, tracker := range c.trackers {
 			// process tracker specific allow/deny list
-			if tracker.ShouldFilter(event) {
+			if !tracker.ShouldFilter(event) {
 				continue
 			}
 
