@@ -15,6 +15,7 @@ import (
 	errorutil "github.com/projectdiscovery/utils/errors"
 	fileutil "github.com/projectdiscovery/utils/file"
 	folderutil "github.com/projectdiscovery/utils/folder"
+	unitutils "github.com/projectdiscovery/utils/unit"
 )
 
 var (
@@ -219,6 +220,8 @@ type Options struct {
 	JSONExport string
 	// JSONLExport is the file to export JSONL output format to
 	JSONLExport string
+	// Redact redacts given keys in
+	Redact goflags.StringSlice
 	// EnableProgressBar enables progress bar
 	EnableProgressBar bool
 	// TemplateDisplay displays the template contents
@@ -277,8 +280,6 @@ type Options struct {
 	SNI string
 	// InputFileMode specifies the mode of input file (jsonl, burp, openapi, swagger, etc)
 	InputFileMode string
-	// DialerTimeout sets the timeout for network requests.
-	DialerTimeout time.Duration
 	// DialerKeepAlive sets the keep alive duration for network requests.
 	DialerKeepAlive time.Duration
 	// Interface to use for network scan
@@ -291,8 +292,6 @@ type Options struct {
 	ResponseReadSize int
 	// ResponseSaveSize is the maximum size of response to save
 	ResponseSaveSize int
-	// ResponseReadTimeout is response read timeout in seconds
-	ResponseReadTimeout time.Duration
 	// Health Check
 	HealthCheck bool
 	// Time to wait between each input read operation before closing the stream
@@ -363,6 +362,12 @@ type Options struct {
 	FuzzingMode string
 	// TlsImpersonate enables TLS impersonation
 	TlsImpersonate bool
+	// DisplayFuzzPoints enables display of fuzz points for fuzzing
+	DisplayFuzzPoints bool
+	// FuzzAggressionLevel is the level of fuzzing aggression (low, medium, high.)
+	FuzzAggressionLevel string
+	// FuzzParamFrequency is the frequency of fuzzing parameters
+	FuzzParamFrequency int
 	// CodeTemplateSignaturePublicKey is the custom public key used to verify the template signature (algorithm is automatically inferred from the length)
 	CodeTemplateSignaturePublicKey string
 	// CodeTemplateSignatureAlgorithm specifies the sign algorithm (rsa, ecdsa)
@@ -379,6 +384,8 @@ type Options struct {
 	ScanID string
 	// ScanName is the name of the scan to be uploaded
 	ScanName string
+	// TeamID is the team ID to use for cloud upload
+	TeamID string
 	// JsConcurrency is the number of concurrent js routines to run
 	JsConcurrency int
 	// SecretsFile is file containing secrets for nuclei
@@ -399,6 +406,79 @@ type Options struct {
 	HttpApiEndpoint string
 	// ListTemplateProfiles lists all available template profiles
 	ListTemplateProfiles bool
+	// timeouts contains various types of timeouts used in nuclei
+	// these timeouts are derived from dial-timeout (-timeout) with known multipliers
+	// This is internally managed and does not need to be set by user by explicitly setting
+	// this overrides the default/derived one
+	timeouts *Timeouts
+}
+
+// SetTimeouts sets the timeout variants to use for the executor
+func (opts *Options) SetTimeouts(t *Timeouts) {
+	opts.timeouts = t
+}
+
+// GetTimeouts returns the timeout variants to use for the executor
+func (eo *Options) GetTimeouts() *Timeouts {
+	if eo.timeouts != nil {
+		// redundant but apply to avoid any potential issues
+		eo.timeouts.ApplyDefaults()
+		return eo.timeouts
+	}
+	// set timeout variant value
+	eo.timeouts = NewTimeoutVariant(eo.Timeout)
+	eo.timeouts.ApplyDefaults()
+	return eo.timeouts
+}
+
+// Timeouts is a struct that contains all the timeout variants for nuclei
+// dialer timeout is used to derive other timeouts
+type Timeouts struct {
+	// DialTimeout for fastdialer (default 10s)
+	DialTimeout time.Duration
+	// Tcp(Network Protocol) Read From Connection Timeout (default 5s)
+	TcpReadTimeout time.Duration
+	// Http Response Header Timeout (default 10s)
+	// this timeout prevents infinite hangs started by server if any
+	// this is temporarily overridden when using @timeout request annotation
+	HttpResponseHeaderTimeout time.Duration
+	// HttpTimeout for http client (default -> 3 x dial-timeout = 30s)
+	HttpTimeout time.Duration
+	// JsCompilerExec timeout/deadline (default -> 2 x dial-timeout = 20s)
+	JsCompilerExecutionTimeout time.Duration
+	// CodeExecutionTimeout for code execution (default -> 3 x dial-timeout = 30s)
+	CodeExecutionTimeout time.Duration
+}
+
+// NewTimeoutVariant creates a new timeout variant with the given dial timeout in seconds
+func NewTimeoutVariant(dialTimeoutSec int) *Timeouts {
+	tv := &Timeouts{
+		DialTimeout: time.Duration(dialTimeoutSec) * time.Second,
+	}
+	tv.ApplyDefaults()
+	return tv
+}
+
+// ApplyDefaults applies default values to timeout variants when missing
+func (tv *Timeouts) ApplyDefaults() {
+	if tv.DialTimeout == 0 {
+		tv.DialTimeout = 10 * time.Second
+	}
+	if tv.TcpReadTimeout == 0 {
+		tv.TcpReadTimeout = 5 * time.Second
+	}
+	if tv.HttpResponseHeaderTimeout == 0 {
+		tv.HttpResponseHeaderTimeout = 10 * time.Second
+	}
+	if tv.HttpTimeout == 0 {
+		tv.HttpTimeout = 3 * tv.DialTimeout
+	}
+	if tv.JsCompilerExecutionTimeout == 0 {
+		tv.JsCompilerExecutionTimeout = 2 * tv.DialTimeout
+	}
+	if tv.CodeExecutionTimeout == 0 {
+		tv.CodeExecutionTimeout = 3 * tv.DialTimeout
+	}
 }
 
 // ShouldLoadResume resume file
@@ -435,9 +515,8 @@ func DefaultOptions() *Options {
 		Timeout:                 5,
 		Retries:                 1,
 		MaxHostError:            30,
-		ResponseReadSize:        10 * 1024 * 1024,
-		ResponseSaveSize:        1024 * 1024,
-		ResponseReadTimeout:     5 * time.Second,
+		ResponseReadSize:        10 * unitutils.Mega,
+		ResponseSaveSize:        unitutils.Mega,
 	}
 }
 
@@ -517,7 +596,7 @@ func (o *Options) GetValidAbsPath(helperFilePath, templatePath string) (string,
 	return "", errorutil.New("access to helper file %v denied", helperFilePath)
 }
 
-// isRootDir checks if given is root directory
+// isHomeDir checks if given is home directory
 func isHomeDir(path string) bool {
 	homeDir := folderutil.HomeDirOrDefault("")
 	return strings.HasPrefix(path, homeDir)
